package com.yn.bftl.thirdparty.common.service;

/**
 * @Author: mingwei
 * @Date:2021/12/2
 * @Description:
 */
public interface PushMessageCustomerService {

    //微信-订单待支付消息推送
    public String push(Long orderId);
    //订单待发货消息推送
    public String toDeliverPush(Long orderId);
    //订单待提货消息推送
    public String pickPush(Long orderId);

    //订单发货消息推送
    public String deliverPush(Long shippingId);
    //订单退款消息推送
    public String refundPush(Long refundId);
    //商品回寄消息推送
    public String returnPush(Long returnId);
    //评价推送
    public String evaluatePush(Long orderId);

}
